#
# spec file for package python-jaraco.text
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jaraco.text
Version:        4.0.0
Release:        2.1
Summary:        Tools to work with text
License:        MIT
URL:            https://github.com/jaraco/jaraco.text
Source0:        https://files.pythonhosted.org/packages/source/j/jaraco.text/jaraco_text-%{version}.tar.gz
BuildRequires:  %{python_module autocommand}
BuildRequires:  %{python_module importlib_resources if %python-base < 3.9}
BuildRequires:  %{python_module inflect}
BuildRequires:  %{python_module jaraco.context >= 4.1}
BuildRequires:  %{python_module jaraco.functools}
BuildRequires:  %{python_module more-itertools}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if 0%{?python_version_nodots} < 39
Requires:       python-importlib_resources
%endif
Requires:       python-autocommand
Requires:       python-inflect
Requires:       python-jaraco.context >= 4.1
Requires:       python-jaraco.functools
Requires:       python-more-itertools
BuildArch:      noarch
%python_subpackages

%description
This package provides handy routines for dealing with text, such as
wrapping, substitution, trimming, stripping, prefix and suffix removal,
line continuation, indentation, comment processing, identifier processing,
values parsing, case insensitive comparison, and more.

%prep
%setup -q -n jaraco_text-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# no pathlib2 in the distro
rm conftest.py
%{python_expand # workaround for gh#jaraco/jaraco.text#10 without pathlib2
if [ %{$python_version_nodots} -lt 310 ]; then
  $python_donttest="or read_newlines or report_newlines"
fi
}
%pytest -k "not (dummyprefix ${$python_donttest})"

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/jaraco/text
%{python_sitelib}/jaraco[_.]text-%{version}.dist-info

%changelog
* Tue Apr  1 2025 Markéta Machová <mmachova@suse.com>
- Make it compatible with older setuptools
* Wed Mar 26 2025 Steve Kowalik <steven.kowalik@suse.com>
- Normalize metadata directory name.
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 4.0.0:
  * Made 'inflect' an optional dependency. The show-newlines
    script now will crash unless jaraco.text[inflect] is
    installed.
* Wed Oct 23 2024 Dirk Müller <dmueller@suse.com>
- update to 3.14.0:
  * Add new 'clean' function, extracted from 'yield_lines'.
  * Fix EncodingWarning.
  * Add 'lines_from' function.
* Sun Dec 17 2023 Dirk Müller <dmueller@suse.com>
- update to 3.12.0:
  * Require Python 3.8 or later.
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Fix build error.
* Thu Jun  1 2023 Dirk Müller <dmueller@suse.com>
- use python3 module python for sle15
* Tue May  9 2023 Dirk Müller <dmueller@suse.com>
- update to 3.11.1:
  * Fixed ``EncodingWarnings`` when reading/writing text.
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.11.0
  * Added strip-prefix script.
* Tue Oct 25 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.10.0:
  - Prefer casefold in FoldedCase.
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Update to v3.9.1
  * #10: Fixed broken tests in ``read_newlines`` and
  ``show-newlines``.
- Release 3.9.0
  * Add ``jaraco.text.show-newlines`` script.
- Release 3.8.1
  * Refreshed packaging.
* Tue Jun 28 2022 Adrian Schröter <adrian@suse.de>
- Update to version 3.8.0:
  * Added ``layouts`` module and ``to-qwerty`` and ``to-dvorak`` scripts.
  * Introducing ``yield_lines``, ``drop_comment``, and ``join_continuation``.
- droping dependency to jaraco.base
* Tue Nov 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.6.0:
  * Fixed DeprecationWarning in importlib.resources.read_text.
  * #5: Fixed warning in docs builds.
* Sat May 15 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * skip python2
- update to version 3.5.0:
  * Rely on PEP 420 for namespace package.
- changes from version 3.4.0:
  * Added WordSet.trim* methods.
- changes from version 3.3.0:
  * Require Python 3.6 or later.
* Sat Mar 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build on older openSUSE releases as with py3.6 we need the
  importlib_resources too
* Thu Jan 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.0:
  * Added normalize_newlines function.
  * Added wrap and unwrap functions and lorem_ipsum attribute containing the Lorem Ipsum sample text.
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0:
  * Remove collections dependency to avoid buildcycle
- Remove multibuild as per above
* Wed Feb 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use multibuild to avoid buildcycle
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Add LICENSE
- Compile manually due to switch to pkgutil namespace technique
- Add fdupes
- Remove bcond_with test, allowing tests suite to run
- Add missing build dependency jaraco.collections
- Remove undesirable build dependencies pytest-flake8, pytest-sugar and
  collective.checkdocs
- Add missing runtime dependencies six, jaraco.base, jaraco.collections
  and jaraco.functools
- Update to v2.0
  * Switch to pkgutil namespace technique for the ``jaraco`` namespace.
* Thu Aug 23 2018 dheidler@suse.de
- Initial Package for v1.10.1
